Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var APIKey apiKeyV2
var ActionV2 actionV2
var ActorV2 actorV2
var AlertActorV2 alertActorV2
var AlertAttributeEntryV2 alertAttributeEntryV2
var AlertAttributeV2 alertAttributeV2
var AlertAttributeValueV2 alertAttributeValueV2
var AlertSlimV2 alertSlimV2
var AlertSourceV2 alertSourceV2
var AlertV2 alertV2
var ChatChannelSlimV2 chatChannelSlimV2
var CustomFieldEntryV1 customFieldEntryV1
var CustomFieldEntryV2 customFieldEntryV2
var CustomFieldOptionV1 customFieldOptionV1
var CustomFieldOptionV2 customFieldOptionV2
var CustomFieldTypeInfoV1 customFieldTypeInfoV1
var CustomFieldTypeInfoV2 customFieldTypeInfoV2
var CustomFieldV2 customFieldV2
var CustomFieldValueV1 customFieldValueV1
var CustomFieldValueV2 customFieldValueV2
var DateTime dateTime
var EmbeddedCatalogEntryV1 embeddedCatalogEntryV1
var EmbeddedCatalogEntryV2 embeddedCatalogEntryV2
var EmbeddedIncidentRoleV2 embeddedIncidentRoleV2
var EscalationCreatorV2 escalationCreatorV2
var EscalationEventV2 escalationEventV2
var EscalationPriorityV2 escalationPriorityV2
var EscalationV2 escalationV2
var ExternalIssueReferenceV2 externalIssueReferenceV2
var ExternalResourceV1 externalResourceV1
var FollowUpPriorityV2 followUpPriorityV2
var FollowUpV2 followUpV2
var IncidentAttachmentV1 incidentAttachmentV1
var IncidentRoleAssignmentV1 incidentRoleAssignmentV1
var IncidentRoleAssignmentV2 incidentRoleAssignmentV2
var IncidentRoleV1 incidentRoleV1
var IncidentRoleV2 incidentRoleV2
var IncidentSlimV2 incidentSlimV2
var IncidentStatusV1 incidentStatusV1
var IncidentStatusV2 incidentStatusV2
var IncidentTimestampV2 incidentTimestampV2
var IncidentTimestampValueV2 incidentTimestampValueV2
var IncidentTimestampWithValueV2 incidentTimestampWithValueV2
var IncidentTypeV1 incidentTypeV1
var IncidentTypeV2 incidentTypeV2
var IncidentUpdateV2 incidentUpdateV2
var IncidentV2 incidentV2
var SeverityV1 severityV1
var SeverityV2 severityV2
var UserV1 userV1
var UserV2 userV2
var UserWithRolesV2 userWithRolesV2
var WorkflowActorV2 workflowActorV2
Functions ¶
func DumpToMap ¶
As a shortcut for simple leaf nodes we can just dump everything (we can also dump everything higher level probably too) If we're just going to dump everything why bother with serialisers? Good question. a) Initial thoughts were that we want some control on the fields we output potentially - for example ignoring deprecated fields. b) We also might need to be cleverer when it comes to catalog config that enables / disables optional fields in the output.
Keeping this as a single callsite so it's easy to find where we're doing this in future.
Types ¶
type ArrayItem ¶
type ArrayItem struct {
Type string `json:"type"`
Properties map[string]Property `json:"properties,omitempty"`
}
ArrayItem is the type and properties of an item in an array.
type Property ¶
type Property struct {
// Types is a list of types that this property can be, e.g. "string" or "integer".
Types []string `json:"type"`
// CustomFormat is a custom format for this property, e.g. "date-time".
CustomFormat string `json:"format,omitempty"`
// For nested structures a property can have its own properties.
Properties map[string]Property `json:"properties,omitempty"`
// For array structures we define the type of the items in the array
Items *ArrayItem `json:"items,omitempty"`
}
Property is a property in a JSON schema.
func (Property) IsDateTime ¶
type Schema ¶
type Schema struct {
// Type is the type of the schema, e.g. "object" - for some reason singer docs
// have this as an array and often nullable eg: `"type": ["null", "object"]`
Type []string `json:"type"`
// HasAdditionalProperties indicates whether the schema allows additional properties
// not defined in the schema.
HasAdditionalProperties bool `json:"additionalProperties"`
// Properties is a map of property names to their schema.
Properties map[string]Property `json:"properties"`
}
Schema is a JSON schema for a stream.
Source Files
¶
- action_v2.go
- actor_v2.go
- alert_actor_v2.go
- alert_attribute_entry_v2.go
- alert_attribute_v2.go
- alert_attribute_value_v2.go
- alert_slim_v2.go
- alert_source_v2.go
- alert_v2.go
- api_key_v2.go
- base_types.go
- chat_channel_slim_v2.go
- custom_field_entry_v1.go
- custom_field_entry_v2.go
- custom_field_option_v1.go
- custom_field_option_v2.go
- custom_field_type_info_v1.go
- custom_field_type_info_v2.go
- custom_field_v2.go
- custom_field_value_v1.go
- custom_field_value_v2.go
- embedded_catalog_entry_v1.go
- embedded_catalog_entry_v2.go
- escalation_creator_v2.go
- escalation_event_v2.go
- escalation_priority_v2.go
- escalation_v2.go
- external_issue_reference_v2.go
- external_resource_v1.go
- follow_up_priority_v2.go
- follow_up_v2.go
- incident_attachment_v1.go
- incident_role_assignment_v1.go
- incident_role_assignment_v2.go
- incident_role_v1.go
- incident_role_v2.go
- incident_slim_v2.go
- incident_status_v1.go
- incident_status_v2.go
- incident_timestamp_v2.go
- incident_timestamp_value_v2.go
- incident_timestamp_with_value_v2.go
- incident_type_v1.go
- incident_type_v2.go
- incident_update_v2.go
- incident_v2.go
- schema.go
- severity_v2.go
- user_v1.go
- user_v2.go
- user_with_roles_v2.go
- workflow_actor_v2.go